Croxy OpenAPI
Cuộn xuống để xem ví dụ mã, ví dụ yêu cầu và ví dụ phản hồi.
Bạn có thể tìm app_key trên trang chủ của trung tâm cá nhân sau khi đăng nhập.
Hãy giữ khóa này an toàn. Khóa này cấp quyền quản trị cho tài khoản của bạn.
Xác thực
App Key
Truyền app_key trong tham số POST:
app_key: {your_app_key}
Hoặc truyền dưới dạng tham số truy vấn:
?app_key={your_app_key}
Định dạng phản hồi
Tất cả endpoint đều trả về một cấu trúc JSON thống nhất:
{
"code": 200,
"message": "Thao tác thành công",
"data": {}
}
code: Mã trạng thái.200nghĩa là thành công; các giá trị khác nghĩa là yêu cầu thất bại.message: Thông điệp phản hồi.data: Dữ liệu phản hồi.
URL cơ sở:
Xác thực
- Xác thực HTTP, scheme: bearer
- API Key (
apiKeyAuth)- Tên tham số: app_key, trong
query. Hỗ trợ cả yêu cầu GET và POST.
- Tên tham số: app_key, trong
Quản lý tài khoản proxy
Danh sách tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/whitelist-account/list?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/whitelist-account/list
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Khóa xác thực |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"id": 0,
"username": "string",
"password": "string",
"created_at": "string",
"remark": "string",
"product_type": 9,
"usage_flow": 0,
"limit_flow": 102400,
"status": 0
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | responseCode | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» id | integer | false | none | Số tài khoản |
| »»» username | string | false | none | Tên tài khoản đại lý |
| »»» password | string | false | none | Mật khẩu tài khoản đại lý |
| »»» created_at | string | false | none | Thêm thời gian |
| »»» remark | string | false | none | Nhận xét |
| »»» product_type | productTypes | false | none | Loại gói, 9 gói giao thông dân cư động, 11 IP dân cư động, 14 IP trung tâm dữ liệu tĩnh, 25 IP dân cư tĩnh |
| »»» usage_flow | integer | false | none | Lưu lượng đã sử dụng, đơn vị: KB |
| »»» limit_flow | integer | false | none | Giới hạn lưu lượng tùy chỉnh: đơn vị GB tối đa là 102400, 0 là không giới hạn |
| »»» status | integer | false | none | Trạng thái đã bật: 1 đã bật, 0 đã tắt |
Enumerated Values
| Property | Value |
|---|---|
| product_type | 9 |
| product_type | 11 |
| product_type | 14 |
| product_type | 25 |
Thêm tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/add \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/add
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01:pass,user02:pass,user03:pass",
"remark": "",
"product_type": 9
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » accounts | body | string | false | Mật khẩu tài khoản, vui lòng điền theo định dạng tên người dùng: mật khẩu. Tài khoản và mật khẩu chỉ hỗ trợ số và chữ cái. Cấm nhập bất kỳ ký hiệu hoặc dấu cách đặc biệt nào. Dấu hai chấm ngăn cách tài khoản và mật khẩu. Tính năng bổ sung hàng loạt được hỗ trợ và các tài khoản đại lý được phân tách bằng dấu phẩy tiếng Anh (,). |
| » remark | body | string | false | Mô tả tài khoản đại lý |
| » product_type | body | productTypes | false | Loại gói, 9 gói giao thông dân cư động, 11 IP dân cư động, 14 IP trung tâm dữ liệu tĩnh, 25 IP dân cư tĩnh |
Enumerated Values
| Parameter | Value |
|---|---|
| » product_type | 9 |
| » product_type | 11 |
| » product_type | 14 |
| » product_type | 25 |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Xóa tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/delete \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/delete
Xin lưu ý rằng nó không thể được khôi phục sau khi xóa và không thể truy vấn lưu lượng đã sử dụng. Sẽ có thời gian chờ khoảng 5 phút để xóa, trong thời gian đó bạn vẫn có thể bị tính phí.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01,user02"
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » accounts | body | string | false | Tài khoản đại lý, chỉ hỗ trợ số và chữ cái. Hỗ trợ thao tác hàng loạt, dấu phẩy tiếng Anh (,) phân tách tài khoản đại lý |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Vô hiệu hóa tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/disable \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/disable
Sẽ có thời gian chờ khoảng 5 phút để vô hiệu hóa, trong thời gian đó bạn vẫn có thể bị tính phí.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01,user02"
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » accounts | body | string | false | Tài khoản đại lý, chỉ hỗ trợ số và chữ cái. Hỗ trợ thao tác hàng loạt, dấu phẩy tiếng Anh (,) phân tách tài khoản đại lý |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Kích hoạt tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/enable \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/enable
Body parameter
{
"app_key": "stringstringstringstringstringst",
"accounts": "user01,user02"
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » accounts | body | string | false | Tài khoản đại lý, chỉ hỗ trợ số và chữ cái. Hỗ trợ thao tác hàng loạt, dấu phẩy tiếng Anh (,) phân tách tài khoản đại lý |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Đổi mật khẩu tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/change-password \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/change-password
Xin lưu ý rằng có thời gian chờ 5 phút sau khi sửa đổi, trong thời gian đó mật khẩu cũ vẫn có thể được sử dụng bình thường.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"account": "user",
"password": "pass"
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » account | body | string | false | Tài khoản đại lý, chỉ hỗ trợ số và chữ cái. |
| » password | body | string | false | Mật khẩu mới cho tài khoản đại lý, chỉ hỗ trợ số và chữ. |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Cập nhật ghi chú tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/change-remark \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/change-remark
Body parameter
{
"app_key": "stringstringstringstringstringst",
"account": "user",
"remark": ""
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » account | body | string | false | Tài khoản đại lý, chỉ hỗ trợ số và chữ cái. |
| » remark | body | string | false | Nhận xét mới cho tài khoản đại lý, trong vòng 32 ký tự tiếng Trung hoặc 64 ký tự tiếng Anh. |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Sửa đổi giới hạn lưu lượng tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/whitelist-account/change-limit \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/whitelist-account/change-limit
Xin lưu ý rằng số liệu thống kê lưu lượng truy cập có thể bị trì hoãn trong vòng 5 phút, nghĩa là lưu lượng truy cập thực tế đã sử dụng có thể vượt quá giới hạn này.
Body parameter
{
"app_key": "stringstringstringstringstringst",
"account": "user",
"limit": 0
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » account | body | string | false | Tài khoản đại lý, chỉ hỗ trợ số và chữ cái. |
| » limit | body | integer | false | Giới hạn lưu lượng, đơn vị: GB, 0 nghĩa là không có giới hạn trên |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Cập nhật thông tin tài khoản proxy
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/proxy-account/change \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/proxy-account/change
Sửa đổi mật khẩu tài khoản proxy, nhận xét, giới hạn lưu lượng, giới hạn lưu lượng hàng ngày, trạng thái bật hoặc chuyển đổi UDP.
Body parameter
{
"app_key": "string",
"account": "string",
"password": "string",
"remark": "string",
"limit": 0,
"daily_limit": 0,
"status": 0,
"udp": 0
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » account | body | string | false | Tên tài khoản đại lý |
| » password | body | string | false | Mật khẩu mới, 6-16 chữ số hoặc chữ cái; nếu không được thông qua, nó sẽ không được sửa đổi. |
| » remark | body | string | false | Ghi chú mới |
| » limit | body | integer | false | Giới hạn lưu lượng, đơn vị GB, 0 nghĩa là không giới hạn |
| » daily_limit | body | integer | false | Giới hạn lưu lượng truy cập hàng ngày tính bằng GB, 0 nghĩa là không có giới hạn |
| » status | body | integer | false | Trạng thái đã bật |
| » udp | body | integer | false | Switch hỗ trợ UDP, chỉ có tác dụng với gói loại 14, 16, 21, 25 |
Enumerated Values
| Parameter | Value |
|---|---|
| » status | 0 |
| » status | 1 |
| » udp | 0 |
| » udp | 1 |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Quản lý đơn hàng
Tạo, truy vấn và hủy đơn hàng.
danh sách đặt hàng
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/order/list \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/order/list
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| page_no | query | integer | false | none |
| page_size | query | integer | false | none |
| trade_no | query | string | false | số thứ tự |
| start_time | query | string(date-time) | false | Thời gian bắt đầu (bao gồm), chẳng hạn như 2024-01-01 00:00:00 |
| end_time | query | string(date-time) | false | Thời gian kết thúc (không bao gồm) |
| status | query | integer | false | Trạng thái đơn hàng |
| product_type | query | integer | false | loại sản phẩm |
| invoice | query | integer | false | Trạng thái hóa đơn: 0 không giới hạn 1 đã lập hóa đơn -1 chưa lập hóa đơn (có thể cấp lại) |
| pay_fee_status | query | integer | false | Sàng lọc thanh toán dài và ngắn: 1 Thanh toán vượt mức 2 Thanh toán ngắn |
Detailed descriptions
status: Trạng thái đơn hàng
| Trạng thái | Mô tả |
|---|---|
| 0 | Đang chờ thanh toán |
| 1 | Đã trả tiền |
| 2 | Bị hủy do làm thêm giờ và không thanh toán |
| 3 | Đã hoàn tiền |
product_type: loại sản phẩm | Loại sản phẩm | Mô tả | |---|---| |3|Nạp số dư| |9|Gói lưu lượng động| |11|Gói thời gian toàn cầu năng động V2| |12|Gói lưu lượng IDC dài hạn| |13|Gói lưu lượng IP tĩnh dân dụng| |14|Gói IP tĩnh trung tâm dữ liệu| |15|Gói lưu lượng ISP dài hạn| |16|Gói lưu lượng tĩnh| |17|Gói số lượng IP động| |18|máy quét web| |19|Gia hạn IP tĩnh| |20|Hạn ngạch thay thế IP tĩnh| |21|Gói lưu lượng tĩnh v2| |24|Gói bổ sung giao thông tĩnh| |25|Gói IP tĩnh dân dụng| |26|Lệnh thay thế - Một số kênh thanh toán yêu cầu người dùng điền số tiền theo cách thủ công, chẳng hạn như: tiền ảo. Nếu xảy ra khoản thanh toán ngắn, bạn cần liên hệ với bộ phận dịch vụ khách hàng để thực hiện hoàn trả thông qua sản phẩm này| |27|Serp| |28|Video|
Enumerated Values
| Parameter | Value |
|---|---|
| status | 0 |
| status | 1 |
| status | 2 |
| status | 3 |
| product_type | 3 |
| product_type | 9 |
| product_type | 11 |
| product_type | 12 |
| product_type | 14 |
| product_type | 16 |
| product_type | 17 |
| product_type | 18 |
| product_type | 19 |
| product_type | 21 |
| product_type | 24 |
| product_type | 25 |
| product_type | 26 |
| product_type | 27 |
| product_type | 28 |
| invoice | -1 |
| invoice | 0 |
| invoice | 1 |
| pay_fee_status | 1 |
| pay_fee_status | 2 |
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": {
"list": [
{
"id": 0,
"trade_no": "string",
"out_trade_no": "string",
"product_id": 0,
"product_type": 0,
"amount": 0,
"unit_price": 0.1,
"total_fee": 0.1,
"goods_fee": 0.1,
"pay_fee": 0.1,
"discount_fee": 0.1,
"handling_fee": 0.1,
"refund_fee": 0.1,
"pm_id": 0,
"pm_title": "string",
"pm_logo": "string",
"status": 0,
"title": "string",
"detail": "string",
"region_desc": "string",
"pay_at": "2019-08-24T14:15:22Z",
"pay_timestamp": 0,
"created_at": "2019-08-24T14:15:22Z",
"pay_fee_status": 0,
"invoice": {
"name": "string",
"org_name": "string",
"first_name": "string",
"last_name": "string",
"phone": "string",
"email": "[email protected]",
"role_type": 0,
"vat_id": "string",
"address_country": "string",
"address_city": "string",
"address_line1": "string",
"address_line2": "string",
"address_postal_code": "string"
}
}
],
"pagination": {
"total": 0,
"page_no": 0,
"page_size": 0,
"total_pages": 0
}
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | thành công | Inline |
Cấu trúc phản hồi
Tạo đơn hàng
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/order/create \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/order/create
Vì có nhiều loại gói và mỗi gói có cấu hình khác nhau nên các bạn vui lòng điền thông số theo tình hình thực tế. Việc điền thông số không đúng cách có thể dẫn đến việc tạo đơn hàng không thành công.
ví dụ:
Gia hạn IP tĩnh
{
"pid": ID gói, // lấy được từ giao diện /open/product
"upids": "1,2,3,4,5,6", // Lấy trường id tương ứng từ giao diện /open/ip/get-static-ip
"pm_id": 1 // Lấy từ giao diện /open/Payment/list hoặc /open/Payment/groups
}
Mua IP tĩnh cho khu dân cư
{
"pid": ID gói, // lấy được từ giao diện /open/product
"pm_id": ID phương thức thanh toán, // lấy được từ giao diện /open/Payment/list hoặc /open/Payment/groups
"khu vực_list": "JP,15,333|DE,10,444|US,5,555" // Định dạng: khu vực, số lượng, ASN|khu vực, số lượng, ASN (số ASN tùy chọn)
}
Mua IP trung tâm dữ liệu tĩnh
{
"pid": ID gói, // lấy được từ giao diện /open/product
"pm_id": ID phương thức thanh toán, // lấy được từ giao diện /open/Payment/list hoặc /open/Payment/groups
"khu vực_list": "JP,15,333|DE,10,444|US,5,555" // Định dạng: khu vực, số lượng, ASN|khu vực, số lượng, ASN (số ASN tùy chọn)
}
Mua giao thông dân cư năng động
{
"pid": ID gói, // lấy được từ giao diện /open/product
"pm_id": ID phương thức thanh toán // Lấy từ giao diện /open/Payment/list hoặc /open/Payment/groups
}
Mua lưu lượng quay vòng tĩnh
{
"pid": ID gói, // lấy được từ giao diện /open/product
"pm_id": ID phương thức thanh toán // Lấy từ giao diện /open/Payment/list hoặc /open/Payment/groups
}
Mua lưu lượng truy cập không giới hạn động
{
"pid": ID gói, // lấy được từ giao diện /open/product
"pm_id": ID phương thức thanh toán, // lấy được từ giao diện /open/Payment/list hoặc /open/Payment/groups
"product_sku_bandwidth_id": ID thông số băng thông,
"product_sku_concurrency_id": ID đặc tả đồng thời
}
Nạp lại số dư
{
"pid": ID gói, // lấy được từ giao diện /open/product
"pm_id": ID phương thức thanh toán, // lấy được từ giao diện /open/Payment/list hoặc /open/Payment/groups
"recharge_amount": số tiền nạp lại
}
Body parameter
{
"pid": 0,
"upids": "string",
"amount": 0,
"pm_id": 0,
"region_list": "string",
"coupon_sn": "string",
"use_invitation_registration_discount": true,
"renew_duration": 0,
"product_sku_bandwidth_id": 0,
"product_sku_concurrency_id": 0,
"product_sku_duration_id": 0,
"etd": 1,
"recharge_amount": 0
}
Tham số
| Name | In | Type | Required | Description | | --- | --- | --- | --- | --- | --- | --- | --- | | body | body | object | true | none | | » pid | body | integer | true | ID gói, từ trường id được trả về bởi giao diện /open/product | | » upids | body | string | false | Danh sách ID gói gia hạn (được phân tách bằng dấu phẩy), từ trường id được trả về bởi giao diện /open/user-product/list hoặc /open/ip/get-static-ip | | » amount | body | number | false | Số gói mới mua | | » pm_id | body | integer | true | ID phương thức thanh toán, từ trường id được trả về bởi giao diện /open/thanh toán/danh sách hoặc /open/thanh toán/nhóm | | » region_list | body | string | false | Khi mua IP tĩnh, hãy chỉ định vùng + số lượng + số ASN. Định dạng là: vùng, số lượng, ASN | khu vực, số lượng, ASN. Ví dụ: JP,15,333 | DE,10,444 | US,5,555 (số ASN là tùy chọn) | | » coupon_sn | body | string | false | Số phiếu giảm giá | | » use_invitation_registration_discount | body | boolean | false | Có nên sử dụng lời mời đăng ký giảm giá | | » renew_duration | body | integer | false | Gia hạn IP tĩnh thời gian tùy chọn | | » product_sku_bandwidth_id | body | integer | false | Gói 11: ID gói băng thông | | » product_sku_concurrency_id | body | integer | false | Gói 11: ID gói đồng thời | | » product_sku_duration_id | body | integer | false | Loại gói=11Bắt buộc: ID thông số thời lượng | | » etd | body | integer | false | Bội số thời lượng, lấy từ gói gia hạn_of_time_days, 2 thể hiện số ngày × 2, giá sẽ tăng | | » recharge_amount | body | integer | false | Gói 3: Số tiền nạp |
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": {
"id": 0,
"trade_no": "string",
"out_trade_no": "string",
"product_id": 0,
"product_type": 0,
"amount": 0,
"unit_price": 0.1,
"total_fee": 0.1,
"goods_fee": 0.1,
"pay_fee": 0.1,
"discount_fee": 0.1,
"handling_fee": 0.1,
"refund_fee": 0.1,
"pm_id": 0,
"pm_title": "string",
"pm_logo": "string",
"status": 0,
"title": "string",
"detail": "string",
"region_desc": "string",
"pay_at": "2019-08-24T14:15:22Z",
"pay_timestamp": 0,
"created_at": "2019-08-24T14:15:22Z",
"pay_fee_status": 0,
"invoice": {
"name": "string",
"org_name": "string",
"first_name": "string",
"last_name": "string",
"phone": "string",
"email": "[email protected]",
"role_type": 0,
"vat_id": "string",
"address_country": "string",
"address_city": "string",
"address_line1": "string",
"address_line2": "string",
"address_postal_code": "string"
}
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Đã tạo thành công | Inline |
Cấu trúc phản hồi
Hủy đơn hàng
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/order/close \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/order/close
Body parameter
{
"trade_no": "string"
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | true | none |
| » trade_no | body | string | true | none |
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": {}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Hoạt động thành công | SuccessResponse |
Kiểm tra trước đơn hàng
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/order/check \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/order/check
Được gọi trước khi tạo đơn hàng, nó được sử dụng để xem trước giá cả, chiết khấu, chi tiết gia hạn IP, v.v. Đơn hàng sẽ không thực sự được tạo. Các tham số hoàn toàn giống với /open/order/create.
Body parameter
{
"pid": 0,
"upids": "string",
"amount": 1,
"pm_id": 0,
"region_list": "string",
"coupon_sn": "string",
"renew_duration": "1m",
"product_sku_bandwidth_id": 0,
"product_sku_concurrency_id": 0,
"product_sku_duration_id": 0,
"etd": 1,
"recharge_amount": 0
}
Tham số
| Name | In | Type | Required | Description | | ---------------------------- | ---- | ------- | -------- | ---------------------------------------------------------------- | -------------------- | | body | body | object | true | none | | » pid | body | integer | true | Mã gói | | » upids | body | string | false | Gia hạn IP: danh sách ID gói người dùng, phân tách bằng dấu phẩy | | » amount | body | integer | false | Số lượng mua | | » pm_id | body | integer | true | Mã phương thức thanh toán | | » region_list | body | string | false | Vùng mua IP tĩnh + số lượng, định dạng: ID vùng, số lượng | ID khu vực, số lượng | | » coupon_sn | body | string | false | Số phiếu giảm giá | | » renew_duration | body | string | false | Thời gian gia hạn IP: 1m=1 tháng, 2m=2 tháng, em=cuối tháng sau | | » product_sku_bandwidth_id | body | integer | false | Loại gói=11Bắt buộc: ID thông số băng thông | | » product_sku_concurrency_id | body | integer | false | Loại gói=11Bắt buộc: ID thông số đồng thời | | » product_sku_duration_id | body | integer | false | Loại gói=11Bắt buộc: ID thông số thời lượng | | » etd | body | integer | false | Bội số thời lượng, thu được từ gói gia hạn_of_time_days | | » recharge_amount | body | number | false | Loại gói=3Bắt buộc: số tiền nạp lại |
Enumerated Values
| Parameter | Value |
|---|---|
| » renew_duration | 1m |
| » renew_duration | 2m |
| » renew_duration | em |
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": {
"product_id": 0,
"amount": 0,
"discount_fee": 0.1,
"total_fee": 0.1,
"pay_fee": 0.1,
"product_type": 0,
"title": "string",
"detail": "string",
"ip_result": [
{
"ip": "string",
"price": 0.1,
"country_code": "string",
"current_time": "2019-08-24T14:15:22Z",
"renewal_time": "2019-08-24T14:15:22Z",
"country": {
"name_zh_cn": "string",
"flag": "string",
"square_flag": "string"
}
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Chuyến bay trước thành công | Inline |
Cấu trúc phản hồi
Danh sách trắng IP
Danh sách danh sách trắng IP
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/proxy-ip/list?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/proxy-ip/list
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Khóa xác thực |
| product_type | query | integer | false | Số loại gói |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"ip": "1.1.1.1",
"remark": "string",
"product_type": 0,
"created_at": "string"
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» ip | string | false | none | IP danh sách trắng |
| »»» remark | string | false | none | Nhận xét |
| »»» product_type | integer | false | none | Loại gói |
| »»» created_at | string | false | none | thời gian sáng tạo |
Thêm danh sách trắng IP
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/proxy-ip/add \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/proxy-ip/add
Body parameter
{
"app_key": "string",
"ips": "1.1.1.1,2.2.2.2",
"remark": "string",
"product_type": 0,
"user_product_id": 0
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » ips | body | string | false | Các IP thuộc danh sách trắng cần được thêm vào, phân tách nhiều IP bằng dấu phẩy hoặc dòng mới. |
| » remark | body | string | false | Nhận xét |
| » product_type | body | integer | false | Số loại gói |
| » user_product_id | body | integer | false | ID gói người dùng, bắt buộc khi loại gói là 11 |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Xóa danh sách trắng IP
Ví dụ mã
# You can also use wget
curl -X POST https://api.croxy.com/open/proxy-ip/delete \
-H 'Content-Type: application/json' \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
POST /open/proxy-ip/delete
Body parameter
{
"app_key": "string",
"ips": "1.1.1.1,2.2.2.2",
"verify_type": "string",
"verify_code": "string"
}
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| body | body | object | false | none |
| » app_key | body | string | false | Khóa ủy quyền |
| » ips | body | string | false | IP danh sách trắng cần xóa, nhiều IP được phân tách bằng dấu phẩy |
| » verify_type | body | string | false | Loại xác minh: điện thoại, email, wechat, totp |
| » verify_code | body | string | false | Mã xác minh |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": null
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | null | false | none | none |
Nhật ký lưu lượng
Việc sử dụng lưu lượng truy cập được tóm tắt theo ngày
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/user-usage-flow/total?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/user-usage-flow/total
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Khóa xác thực |
| start_time | query | string(Y-m-d H:i:s) | false | Thời gian bắt đầu, chính xác đến giây. Xin lưu ý rằng việc đăng nhập bị trì hoãn trong vòng 5 phút. Mặc định là trong vòng 7 ngày. |
| end_time | query | string(Y-m-d H:i:s) | false | Thời hạn, chính xác đến từng giây. Xin lưu ý rằng việc đăng nhập bị trì hoãn trong vòng 5 phút. Thời gian hiện tại mặc định. |
| username | query | string | false | Tên tài khoản phụ, truy vấn tất cả các tài khoản theo mặc định, tài khoản phụ có thể được chỉ định. Xin lưu ý rằng nếu bạn thêm tài khoản phụ có cùng tên, truy vấn này sẽ trả về tất cả hồ sơ sử dụng cho tài khoản đại lý có cùng tên. |
| product_type | query | number | false | Loại gói |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"day": "2022-08-01",
"flow": 0
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» day | string | false | none | ngày |
| »»» flow | integer | false | none | Lưu lượng tiêu thụ, đơn vị KB |
Tra cứu gói
Danh sách các gói đã mua
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/user-product/list?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/user-product/list
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Khóa xác thực |
| trade_no | query | string | false | Mã đơn hàng, vui lòng nhập đầy đủ mã đơn hàng. Tìm kiếm mờ không được hỗ trợ. |
| page | query | number | false | Phân trang, mặc định: 1 |
| size | query | number | false | Số trang hiển thị, mặc định: 20 |
| product_type | query | number | false | Loại gói |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"id": 0,
"created_at": "2022-05-13 12:14:15",
"expired_at": "2022-05-13 12:14:15",
"product_type": 9,
"trade_no": "2022051312134339861461465434",
"order": {
"created_at": "2022-05-13 12:13:43",
"pay_at": "2022-05-13 12:13:43",
"title": "cấp độ đầu vào"
}
}
],
"page": 1,
"page_size": 20,
"total_count": 0,
"total_page": 0
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» id | integer | false | none | Số gói |
| »»» created_at | string | false | none | Thời gian hiệu lực của gói |
| »»» expired_at | string | false | none | Thời gian hết hạn của gói. Sau khi hết hạn, lưu lượng không thể được sử dụng. |
| »»» product_type | productTypes | false | none | Loại gói, 9 gói giao thông dân cư động, 11 IP dân cư động, 14 IP trung tâm dữ liệu tĩnh, 25 IP dân cư tĩnh |
| »»» trade_no | string | false | none | Số giao dịch đặt hàng |
| »»» order | object | false | none | none |
| »»»» created_at | string | false | none | Thời gian tạo đơn hàng |
| »»»» pay_at | string | false | none | Thời gian thanh toán đơn hàng |
| »»»» title | string | false | none | Mô tả đơn hàng |
| »» page | integer | false | none | Trang hiện tại |
| »» page_size | integer | false | none | kích thước phân trang |
| »» total_count | integer | false | none | Tổng số hồ sơ |
| »» total_page | integer | false | none | Tổng số trang |
Enumerated Values
| Property | Value |
|---|---|
| product_type | 9 |
| product_type | 11 |
| product_type | 14 |
| product_type | 25 |
Tóm tắt dữ liệu gói người dùng
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/user-product/summary?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/user-product/summary
Nhận thông tin tóm tắt thống kê về các gói người dùng, bao gồm tổng số tiền, số tiền hiệu dụng, số tiền sắp hết, số tiền đã hết hạn, v.v.
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | Khóa xác thực |
| product_type | query | integer | false | Loại sản phẩm, chỉ hỗ trợ 9 (gói lưu lượng động), 12 (gói lưu lượng IDC dài hạn) |
Enumerated Values
| Parameter | Value |
|---|---|
| product_type | 9 |
| product_type | 12 |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "thành công",
"data": {
"total": 1048576,
"total_count": 5,
"effective": 524288,
"effective_count": 3,
"effective_total": 786432,
"effective_used": 262144,
"temporary": 102400,
"temporary_count": 1,
"expired": 51200,
"expired_count": 1,
"used": 473088
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» total | integer | false | none | Lưu lượng/Tổng khối lượng IP (đơn vị: KB) |
| »» total_count | integer | false | none | Tổng số gói |
| »» effective | integer | false | none | Số tiền còn hiệu lực (đơn vị: KB) |
| »» effective_count | integer | false | none | Số gói hợp lệ |
| »» effective_total | integer | false | none | Tổng số tiền hiệu dụng (đơn vị: KB) |
| »» effective_used | integer | false | none | Lượng sử dụng hiệu quả (đơn vị: KB) |
| »» temporary | integer | false | none | Tổng số tiền phải trả (phải trả trong vòng 7 ngày, đơn vị: KB) |
| »» temporary_count | integer | false | none | Số gói hết hạn (hết hạn trong 7 ngày) |
| »» expired | integer | false | none | Số tiền còn lại đã hết hạn (đơn vị: KB) |
| »» expired_count | integer | false | none | Số gói hết hạn |
| »» used | integer | false | none | Tổng số tiền sử dụng (đơn vị: KB) |
Lấy IP
Trích xuất IP
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/v3?app_key=pa%24%24word \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/v3
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| app_key | query | string(password) | true | phím truy cập |
| cc | query | string | false | Quốc gia hoặc khu vực |
| state | query | string | false | tỉnh hoặc tiểu bang |
| city | query | string | false | Thành phố |
| format | query | string | false | Nhận định dạng |
| lb | query | string | false | Dấu phân cách, chỉ hợp lệ ở định dạng văn bản |
| num | query | number | false | Trích xuất số lượng |
| life | query | number | false | Thời gian giữ - phút |
| ep | query | string | false | mạng proxy |
Enumerated Values
| Parameter | Value |
|---|---|
| ep | us |
| ep | hk |
| ep | de |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
[
"150.109.114.72:1140",
"150.109.114.72:1141",
"150.109.114.72:1142",
"150.109.114.72:1143",
"150.109.114.72:1144",
"150.109.114.72:1145",
"150.109.114.72:1146",
"150.109.114.72:1147",
"150.109.114.72:1148",
"150.109.114.72:1149"
]
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [any] | false | none | none |
Danh sách thành phố khu vực năng động V4
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dcl4?username=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dcl4
Lấy danh sách thành phố theo tên người dùng, yêu cầu xác thực đăng nhập và tài khoản phải thuộc về người dùng hiện tại
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| username | query | string | true | Tên người dùng tài khoản đại lý |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"cache": true,
"list": [
{
"City": "Los Angeles",
"Area": "US",
"State": "California"
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» cache | boolean | false | none | Cho dù nó đến từ bộ nhớ đệm |
| »» list | [object] | false | none | none |
| »»» City | string | false | none | Thành phố |
| »»» Area | string | false | none | khu vực |
| »»» State | string | false | none | Tiểu bang/Tỉnh |
Danh sách tỉnh/bang khu vực động V4
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dsl4?username=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dsl4
Nhận danh sách tiểu bang/tỉnh theo tên người dùng, yêu cầu xác thực đăng nhập và tài khoản phải thuộc về người dùng hiện tại
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| username | query | string | true | Tên người dùng tài khoản đại lý |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"cache": true,
"list": [
{
"City": "Los Angeles",
"Area": "US",
"State": "California"
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» cache | boolean | false | none | Cho dù nó đến từ bộ nhớ đệm |
| »» list | [object] | false | none | none |
| »»» City | string | false | none | Thành phố |
| »»» Area | string | false | none | khu vực |
| »»» State | string | false | none | Tiểu bang/Tỉnh |
Danh sách hợp nhất thành phố/tỉnh khu vực năng động V4
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dal4?username=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dal4
Nhận danh sách hợp nhất các tiểu bang/tỉnh và thành phố theo tên người dùng, được nhóm theo khu vực. Cần phải xác thực đăng nhập và tài khoản phải thuộc về người dùng hiện tại
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| username | query | string | true | Tên người dùng tài khoản đại lý |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"cache": true,
"list": [
{
"Area": "US",
"states": [
{
"State": "California",
"cities": ["Los Angeles"]
}
]
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» cache | boolean | false | none | Cho dù nó đến từ bộ nhớ đệm |
| »» list | [object] | false | none | Danh sách khu vực |
| »»» Area | string | false | none | mã vùng |
| »»» states | [object] | false | none | Danh sách Tiểu bang/Tỉnh |
| »»»» State | string | false | none | Tên tiểu bang/tỉnh |
| »»»» cities | [string] | false | none | Danh sách thành phố |
Danh sách thành phố
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-citys \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-citys
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"name_zh_cn": "Hoa Kỳ",
"name_en": "United States",
"continent_code": "NA",
"country_code": "US",
"items": [
{
"city": "Arlington",
"state": "alabama",
"continent_code": "NA",
"country_code": "US"
}
]
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | danh sách |
| »»» name_zh_cn | string | false | none | Tên quốc gia hoặc khu vực |
| »»» name_en | string | false | none | Tên quốc gia hoặc khu vực |
| »»» continent_code | string | false | none | mã lục địa |
| »»» country_code | string | false | none | Mã quốc gia hoặc vùng |
| »»» items | [any] | false | none | tỉnh hoặc tiểu bang |
| »»»» city | string | false | none | tên thành phố |
| »»»» state | string | false | none | Mã tên tỉnh hoặc tiểu bang |
| »»»» continent_code | string | false | none | mã lục địa |
| »»»» country_code | string | false | none | Mã quốc gia hoặc vùng |
Tìm kiếm thành phố
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-citys/search?country_code=string&state=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-citys/search
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| country_code | query | string | true | Mã quốc gia hoặc vùng |
| state | query | string | true | Mã tiểu bang hoặc tỉnh |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": ["string"]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [string] | false | none | danh sách |
Danh sách tiểu bang
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-states \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-states
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": [
{
"name_zh_cn": "Hoa Kỳ",
"name_en": "United States",
"continent_code": "NA",
"country_code": "US",
"items": [
{
"state": "alabama",
"continent_code": "NA",
"country_code": "US"
}
]
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | danh sách |
| »»» name_zh_cn | string | false | none | Tên quốc gia hoặc khu vực |
| »»» name_en | string | false | none | Tên quốc gia hoặc khu vực |
| »»» continent_code | string | false | none | mã lục địa |
| »»» country_code | string | false | none | Mã quốc gia hoặc vùng |
| »»» items | [any] | false | none | tỉnh hoặc tiểu bang |
| »»»» state | string | false | none | Mã tên tỉnh hoặc tiểu bang |
| »»»» continent_code | string | false | none | mã lục địa |
| »»»» country_code | string | false | none | Mã quốc gia hoặc vùng |
Tìm kiếm Tiểu bang/Tỉnh
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/dynamic-states/search?country_code=string \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/dynamic-states/search
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| country_code | query | string | true | Mã quốc gia hoặc vùng |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "string",
"data": {
"list": ["string"]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ, 156 tài khoản không được xác thực. |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [string] | false | none | danh sách |
Trích xuất danh sách IP tĩnh đã mua
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/get-static-ip \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/get-static-ip
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| country_code | query | string | false | Mã quốc gia hoặc vùng |
| product_type | query | number | false | Loại sản phẩm, 25: IP dân dụng tĩnh, 14: IP trung tâm dữ liệu |
| trade_no | query | string | false | Lọc IP theo số đơn hàng |
| page | query | number | false | số trang |
| size | query | number | false | Số lượng mỗi trang |
| status | query | number | false | Trạng thái, 1: hợp lệ, 2: không hợp lệ, 3: sắp hết hạn, 4: đang bảo trì |
Enumerated Values
| Parameter | Value |
|---|---|
| product_type | 14 |
| product_type | 25 |
| status | 1 - 2 - 3 - 4 |
Phản hồi
| Status | Meaning | Description | Schema |
|---|
Lấy số lượng IP tĩnh đang bán trong khu vực
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/ip/static-ip-region \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/ip/static-ip-region
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| isp | query | integer | false | Lọc ISP, không lọc nếu không truyền (mặc định là 1 ngoại trừ trang 1/4/5) |
| asn | query | integer | false | Có trả về dữ liệu gói ASN hay không |
| exclusive | query | integer | false | Có tính theo hàng tồn kho độc quyền hay không |
Detailed descriptions
isp: Lọc ISP, không lọc nếu không truyền (mặc định là 1 ngoại trừ trang 1/4/5)
| giá trị | mô tả |
|---|---|
| 0 | Trung tâm dữ liệu IP tĩnh (IDC) |
| 1 | Trang chủ IP tĩnh (ISP) |
asn: Có trả về dữ liệu gói ASN hay không
| giá trị | mô tả |
|---|---|
| 0 | Không trả về dữ liệu gói ASN (mặc định) |
| 1 | Trả về dữ liệu gói ASN |
exclusive: Có tính theo hàng tồn kho độc quyền hay không
| giá trị | mô tả |
|---|---|
| 0 | Thống kê dựa trên tầm cỡ của người dùng/nhóm chia sẻ hiện tại (mặc định) |
| 1 | Loại trừ tất cả các IP được chỉ định và chỉ tính khoảng không quảng cáo có sẵn |
Enumerated Values
| Parameter | Value |
|---|---|
| isp | 0 |
| isp | 1 |
| asn | 0 |
| asn | 1 |
| exclusive | 0 |
| exclusive | 1 |
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "Yêu cầu thành công",
"data": {
"list": [
{
"code": "US",
"number": 55
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [any] | false | none | none |
| »»» code | string | false | none | Mã quốc gia hoặc vùng |
| »»» number | integer | false | none | Số lượng |
Nhận các quốc gia/khu vực được hỗ trợ bởi Host_pool
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/host-pool/regions \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/host-pool/regions
Truy vấn danh sách các quốc gia/khu vực được trang web hiện tại của dịch vụ hosting_pool hỗ trợ.
Giao diện này hướng đến kịch bản trích xuất ngẫu nhiên IP của trung tâm dữ liệu dựa trên các điểm lưu lượng truy cập và chỉ tính các quốc gia/khu vực dựa trên kho IP của trung tâm dữ liệu có sẵn tại địa điểm hiện tại. ASN, ISP, tính năng lọc khoảng không quảng cáo độc quyền không được hỗ trợ và IP không bị loại trừ khỏi hồ sơ người dùng đã mua.
Ví dụ phản hồi
200 Response
{
"code": 200,
"msg": "Yêu cầu thành công",
"data": {
"list": [
{
"code": "US",
"number": 55,
"name_zh_cn": "Hoa Kỳ",
"name_en": "United States",
"square_flag": "https://example.com/static/flags/us.png"
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | Yêu cầu thành công | Inline |
Cấu trúc phản hồi
Mã trạng thái 200
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| » code | integer | false | none | Mã trạng thái, 200 thành công |
| » msg | string | false | none | thông báo trạng thái |
| » data | object | false | none | none |
| »» list | [object] | false | none | none |
| »»» code | string | false | none | Mã quốc gia hoặc vùng, ISO 3166-1 alpha-2 |
| »»» number | integer | false | none | Số lượng IP trung tâm dữ liệu có sẵn tại địa điểm hiện tại |
| »»» name_zh_cn | string | false | none | Quốc gia hoặc khu vực Tên tiếng Trung |
| »»» name_en | string | false | none | Tên tiếng Anh của quốc gia hoặc khu vực |
| »»» square_flag | string | false | none | URL hình ảnh cờ vuông |
Quản lý thanh toán
Nhận danh sách các phương thức thanh toán
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/payment/groups \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/payment/groups
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| trade_no | query | undefined | false | Số đơn hàng - có thể được chuyển vào khi một số đơn hàng yêu cầu một phương thức thanh toán cụ thể |
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": {
"list": [
{
"name": "string",
"logos": ["string"],
"items": [
{
"id": 0,
"title": "string",
"logo": "string",
"group": "string",
"disabled": false,
"min": 0,
"max": 0
}
]
}
]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | đạt được thành công | Inline |
Cấu trúc phản hồi
Tiếp thị
Tỷ lệ thưởng nạp tiền
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/activity/balance-recharge-gift-ratio \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/activity/balance-recharge-gift-ratio
Tỷ lệ thưởng nạp tiền
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": {
"list": [null]
}
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Inline |
Cấu trúc phản hồi
Sản phẩm
Danh sách sản phẩm
Ví dụ mã
# You can also use wget
curl -X GET https://api.croxy.com/open/product \
-H 'Accept: application/json' \
-H 'Authorization: Bearer {access-token}'
GET /open/product
Nhận danh sách các gói có sẵn để mua trên trang web hiện tại và hỗ trợ lọc theo loại, thời hạn hiệu lực và các điều kiện khác.
Tham số
| Name | In | Type | Required | Description |
|---|---|---|---|---|
| type | query | integer | false | Loại gói, xem mô tả liệt kê Product.type. Nếu không vượt qua, tất cả các loại sẽ được trả về. |
| parent_product_type | query | integer | false | Loại gói gốc, chỉ hợp lệ khi loại=19 (gia hạn IP), dùng để lọc các dòng sản phẩm: 14=trung tâm dữ liệu 25=dân cư |
| time_days | query | any | false | Lọc khoảng thời gian hiệu lực, hỗ trợ giá trị đơn hoặc mảng, chẳng hạn như 30 / [30,90,365] |
| show_type | query | any | false | Lọc kiểu hiển thị, hỗ trợ giá trị đơn hoặc mảng |
Enumerated Values
| Parameter | Value |
|---|---|
| parent_product_type | 14 |
| parent_product_type | 25 |
Ví dụ phản hồi
200 Response
{
"code": 0,
"message": "Hoạt động thành công",
"data": [
{
"id": 0,
"title": "string",
"type": 0,
"show_type": 0,
"status": 0,
"price": 0.1,
"usd_price": 0.1,
"price_hkd": 0.1,
"original_price": 0.1,
"original_usd_price": 0.1,
"original_price_hkd": 0.1,
"local_price": 0.1,
"local_original_price": 0.1,
"preferred_currency": "string",
"support_currencies": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"balance_value": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"time_days": 0,
"tip1": "string",
"tip2": "string",
"introduce": ["string"],
"region_list_id": 0,
"renew_product_list": "string",
"parent_product_type": 0,
"total_count": 0,
"remain_count": 0,
"extension_of_time_days": [0],
"time_days_price_rate": 0.1,
"desc": {
"subtitle": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"tip1": "string",
"tip2": "string",
"introduce": ["string"]
},
"sku": {
"bandwidth_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"duration_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"concurrency_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
]
}
}
]
}
Phản hồi
| Status | Meaning | Description | Schema |
|---|---|---|---|
| 200 | OK | OK | Inline |
Cấu trúc phản hồi
Schemas
productTypes
9
Loại gói, 9 gói giao thông dân cư động, 11 IP dân cư động, 14 IP trung tâm dữ liệu tĩnh, 25 IP dân cư tĩnh
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| anonymous | integer | false | none | Loại gói, 9 gói giao thông dân cư động, 11 IP dân cư động, 14 IP trung tâm dữ liệu tĩnh, 25 IP dân cư tĩnh |
Enumerated Values
| Property | Value |
|---|---|
| anonymous | 9 |
| anonymous | 11 |
| anonymous | 14 |
| anonymous | 25 |
apiKey
{}
Khóa xác thực
Properties
None
responseCode
200
Mã trạng thái, 200 thành công, 3 app_key không hợp lệ
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| anonymous | integer | false | none | Mã trạng thái, 200 thành công, 3 app_key không hợp lệ |
responseMsg
"thành công"
Thông điệp phản hồi
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| anonymous | string | false | none | Thông điệp phản hồi |
SuccessResponse
{
"code": 0,
"message": "Hoạt động thành công",
"data": {}
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| code | integer | false | none | none |
| message | string | false | none | none |
| data | object | false | none | none |
ErrorResponse
{
"code": 400,
"message": "Lỗi tham số",
"errors": {}
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| code | integer | false | none | none |
| message | string | false | none | none |
| errors | object | false | none | none |
User
{
"id": 0,
"email": "[email protected]",
"phone": "string",
"balance": 0.1,
"status": 0,
"is_real_name": true,
"created_at": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| string(email) | false | none | none | |
| phone | string | false | none | none |
| balance | number(float) | false | none | none |
| status | integer | false | none | none |
| is_real_name | boolean | false | none | none |
| created_at | string(date-time) | false | none | none |
Order
{
"id": 0,
"trade_no": "string",
"out_trade_no": "string",
"product_id": 0,
"product_type": 0,
"amount": 0,
"unit_price": 0.1,
"total_fee": 0.1,
"goods_fee": 0.1,
"pay_fee": 0.1,
"discount_fee": 0.1,
"handling_fee": 0.1,
"refund_fee": 0.1,
"pm_id": 0,
"pm_title": "string",
"pm_logo": "string",
"status": 0,
"title": "string",
"detail": "string",
"region_desc": "string",
"pay_at": "2019-08-24T14:15:22Z",
"pay_timestamp": 0,
"created_at": "2019-08-24T14:15:22Z",
"pay_fee_status": 0,
"invoice": {
"name": "string",
"org_name": "string",
"first_name": "string",
"last_name": "string",
"phone": "string",
"email": "[email protected]",
"role_type": 0,
"vat_id": "string",
"address_country": "string",
"address_city": "string",
"address_line1": "string",
"address_line2": "string",
"address_postal_code": "string"
}
}
Properties
| Name | Type | Required | Restrictions | Description | | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | | id | integer | false | none | ID đơn hàng | | trade_no | string | false | none | Số đơn hàng nội bộ | | out_trade_no | string | false | none | Số đơn đặt hàng bên ngoài | | product_id | integer | false | none | Mã gói | | product_type | integer | false | none | Loại gói, xem liệt kê loại sản phẩm | | amount | integer | false | none | Số lượng mua | | unit_price | number(float) | false | none | đơn giá | | total_fee | number(float) | false | none | Tổng giá trị đơn hàng (không bao gồm chiết khấu và phí xử lý) | | goods_fee | number(float) | false | none | Giá sản phẩm (đã bao gồm chiết khấu, chưa bao gồm phí xử lý) | | pay_fee | number(float) | false | none | Số tiền thực tế thanh toán (bao gồm chiết khấu và phí xử lý) | | discount_fee | number(float) | false | none | Số tiền chiết khấu | | handling_fee | number(float) | false | none | phí xử lý | | refund_fee | number(float) | false | none | Số tiền hoàn lại | | pm_id | integer | false | none | ID phương thức thanh toán (từ /open/thanh toán/danh sách) | | pm_title | string | false | none | Tên phương thức thanh toán | | pm_logo | string | false | none | URL biểu trưng của phương thức thanh toán | | status | integer | false | none | Trạng thái đơn hàng
| giá trị | mô tả |
| --- | --- |
| 0 | Đang chờ thanh toán |
| 1 | Đã trả tiền |
| 2 | Hủy thời gian chờ |
| 3 | Đã hoàn tiền | | | title | string | false | none | Tiêu đề gói | | detail | string | false | none | Mô tả gói | | region_desc | string | false | none | Mô tả đặc điểm kỹ thuật khu vực | | pay_at | string(date-time) | false | none | thời gian thanh toán | | pay_timestamp | integer | false | none | Dấu thời gian thanh toán | | created_at | string(date-time) | false | none | thời gian sáng tạo | | pay_fee_status | integer | false | none | Trạng thái thanh toán dài và ngắn: 0 bình thường 1 thanh toán dài (thanh toán vượt mức) 2 thanh toán ngắn | | invoice | object | false | none | Thông tin hóa đơn (chỉ có giá trị đối với đơn hàng thanh toán trực tuyến) | | » name | string | false | none | tên đầy đủ | | » org_name | string | false | none | Tên công ty | | » first_name | string | false | none | none | | » last_name | string | false | none | none | | » phone | string | false | none | none | | » email | string(email) | false | none | none | | » role_type | integer | false | none | 1 người 2 công ty | | » vat_id | string | false | none | Mã số thuế | | » address_country | string | false | none | none | | » address_city | string | false | none | none | | » address_line1 | string | false | none | none | | » address_line2 | string | false | none | none | | » address_postal_code | string | false | none | none |
OrderCheckResult
{
"product_id": 0,
"amount": 0,
"discount_fee": 0.1,
"total_fee": 0.1,
"pay_fee": 0.1,
"product_type": 0,
"title": "string",
"detail": "string",
"ip_result": [
{
"ip": "string",
"price": 0.1,
"country_code": "string",
"current_time": "2019-08-24T14:15:22Z",
"renewal_time": "2019-08-24T14:15:22Z",
"country": {
"name_zh_cn": "string",
"flag": "string",
"square_flag": "string"
}
}
]
}
Đặt hàng kết quả kiểm tra trước
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| product_id | integer | false | none | Mã gói |
| amount | integer | false | none | Số lượng |
| discount_fee | number(float) | false | none | Số tiền chiết khấu |
| total_fee | number(float) | false | none | Tổng số đơn đặt hàng |
| pay_fee | number(float) | false | none | Số tiền thực trả |
| product_type | integer | false | none | Loại gói |
| title | string | false | none | Tiêu đề gói |
| detail | string | false | none | Mô tả gói |
| ip_result | [object] | false | none | Kết quả gia hạn IP hàng loạt (chỉ trả về khi gia hạn IP) |
| » ip | string | false | none | none |
| » price | number(float) | false | none | none |
| » country_code | string | false | none | none |
| » current_time | string(date-time) | false | none | none |
| » renewal_time | string(date-time) | false | none | none |
| » country | object | false | none | none |
| »» name_zh_cn | string | false | none | none |
| »» flag | string | false | none | URL cờ vòng tròn |
| »» square_flag | string | false | none | URL cờ vuông |
Product
{
"id": 0,
"title": "string",
"type": 0,
"show_type": 0,
"status": 0,
"price": 0.1,
"usd_price": 0.1,
"price_hkd": 0.1,
"original_price": 0.1,
"original_usd_price": 0.1,
"original_price_hkd": 0.1,
"local_price": 0.1,
"local_original_price": 0.1,
"preferred_currency": "string",
"support_currencies": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"balance_value": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"time_days": 0,
"tip1": "string",
"tip2": "string",
"introduce": ["string"],
"region_list_id": 0,
"renew_product_list": "string",
"parent_product_type": 0,
"total_count": 0,
"remain_count": 0,
"extension_of_time_days": [0],
"time_days_price_rate": 0.1,
"desc": {
"subtitle": "string",
"flow_value": 0.1,
"flow_give": 0.1,
"balance_give": 0.1,
"time_validity": 0.1,
"time_price": 0.1,
"tip1": "string",
"tip2": "string",
"introduce": ["string"]
},
"sku": {
"bandwidth_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"duration_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
],
"concurrency_list": [
{
"id": 0,
"value": 0,
"price": 0.1,
"price_usd": 0.1,
"price_hkd": 0.1
}
]
}
}
Properties
| Name | Type | Required | Restrictions | Description | | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | | id | integer | false | none | Mã gói | | title | string | false | none | Tiêu đề chính của gói | | type | integer | false | none | Loại gói
| giá trị | mô tả |
| --- | --- |
| 3 | Nạp lại số dư |
| 9 | Gói giao thông dân cư năng động |
| 10 | Gói trọn gói năng động toàn cầu |
| 11 | Gói toàn cầu năng động tùy chỉnh V2 (bao gồm SKU) |
| 12 | Gói lưu lượng IDC dài hạn |
| 13 | Gói lưu lượng IP tĩnh dân dụng |
| 14 | Gói IP tĩnh trung tâm dữ liệu |
| 15 | Gói lưu lượng ISP dài hạn |
| 16 | Gói lưu lượng tĩnh |
| 17 | Gói IP dân dụng năng động |
| 19 | Gói Gia hạn IP tĩnh |
| 20 | Trình độ thay thế IP tĩnh |
| 21 | Gói IP tĩnh dân dụng |
| 24 | Gói bổ sung lưu lượng truy cập tĩnh |
| 25 | Gói cước IP tĩnh | | | show_type | integer | false | none | Loại hiển thị: 1 Thông thường 2 Khuyến nghị lớn 3 Không có sẵn để mua (cần tùy chỉnh) 4 Dùng thử | | status | integer | false | none | Tình trạng: 1 trên kệ, 0 ngoài kệ | | price | number(float) | false | none | giá nhân dân tệ | | usd_price | number(float) | false | none | giá đô la | | price_hkd | number(float) | false | none | Giá đô la Hồng Kông | | original_price | number(float) | false | none | Giá gốc (CNY) | | original_usd_price | number(float) | false | none | Giá gốc (USD) | | original_price_hkd | number(float) | false | none | Giá gốc (HKD) | | local_price | number(float) | false | none | Giá địa phương (phụ thuộc vào ưa thích_currency) | | local_original_price | number(float) | false | none | Giá gốc địa phương hóa (phụ thuộc vào ưa thích_currency) | | preferred_currency | string | false | none | Nên hiển thị loại tiền tệ như usd/cny/hkd | | support_currencies | string | false | none | Danh sách các loại tiền được hỗ trợ, phân tách bằng dấu phẩy, chẳng hạn như usd, cny | | flow_value | number(float) | false | none | Lưu lượng mặc định của gói dữ liệu (GB) | | flow_give | number(float) | false | none | Lưu lượng truy cập miễn phí (GB) | | balance_give | number(float) | false | none | Tiền thưởng nạp lại số dư | | balance_value | number(float) | false | none | Số tiền nạp | | time_validity | number(float) | false | none | Thời hạn hiệu lực mặc định của các gói tiêu chuẩn | | time_price | number(float) | false | none | Giá gói tiêu chuẩn trên mỗi IP | | time_days | integer | false | none | Số ngày có hiệu lực, chẳng hạn như 30/90/180/365 | | tip1 | string | false | none | Mô tả nhãn 1 | | tip2 | string | false | none | Mô tả nhãn 2 | | introduce | [string] | false | none | Danh sách văn bản giới thiệu | | region_list_id | integer | false | none | ID khu vực | | renew_product_list | string | false | none | Danh sách ID gói có thể gia hạn (được phân tách bằng dấu phẩy) | | parent_product_type | integer | false | none | Loại gói gốc (hợp lệ khi loại=19): 14 hoặc 25 | | total_count | integer | false | none | Tổng hàng tồn kho, 0 có nghĩa là không có giới hạn | | remain_count | integer | false | none | hàng còn lại | | extension_of_time_days | [integer] | false | none | Danh sách bội số thời lượng. Nếu nó trống hoặc chỉ chứa 1 thì có nghĩa là nó không được hỗ trợ. | | time_days_price_rate | number(float) | false | none | Hệ số giá thời hạn, giá × (1 + (nhân-1) × tỷ lệ) | | desc | object | false | none | Thông tin mô tả gói | | » subtitle | string | false | none | phụ đề | | » flow_value | number(float) | false | none | none | | » flow_give | number(float) | false | none | none | | » balance_give | number(float) | false | none | none | | » time_validity | number(float) | false | none | none | | » time_price | number(float) | false | none | none | | » tip1 | string | false | none | none | | » tip2 | string | false | none | none | | » introduce | [string] | false | none | none | | sku | object | false | none | Tham số đặc tả (trả về khi loại=11) | | » bandwidth_list | [object] | false | none | Danh sách đặc tả băng thông | | »» id | integer | false | none | none | | »» value | integer | false | none | Giá trị băng thông (Mbps) | | »» price | number(float) | false | none | none | | »» price_usd | number(float) | false | none | none | | »» price_hkd | number(float) | false | none | none | | » duration_list | [object] | false | none | Danh sách đặc tả thời lượng | | »» id | integer | false | none | none | | »» value | integer | false | none | Thời lượng (ngày) | | »» price | number(float) | false | none | none | | »» price_usd | number(float) | false | none | none | | »» price_hkd | number(float) | false | none | none | | » concurrency_list | [object] | false | none | Danh sách đặc tả đồng thời | | »» id | integer | false | none | none | | »» value | integer | false | none | Số lượng đồng thời | | »» price | number(float) | false | none | none | | »» price_usd | number(float) | false | none | none | | »» price_hkd | number(float) | false | none | none |
WhiteIp
{
"id": 0,
"ip": "string",
"remark": "string",
"created_at": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| ip | string | false | none | none |
| remark | string | false | none | none |
| created_at | string(date-time) | false | none | none |
WhitelistAccount
{
"id": 0,
"username": "string",
"limit": 0,
"used": 0,
"status": 0
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| username | string | false | none | none |
| limit | integer | false | none | none |
| used | integer | false | none | none |
| status | integer | false | none | none |
Coupon
{
"id": 0,
"name": "string",
"code": "string",
"discount": 0.1,
"expire_time": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| name | string | false | none | none |
| code | string | false | none | none |
| discount | number(float) | false | none | none |
| expire_time | string(date-time) | false | none | none |
Article
{
"id": 0,
"title": "string",
"content": "string",
"created_at": "2019-08-24T14:15:22Z"
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| id | integer | false | none | none |
| title | string | false | none | none |
| content | string | false | none | none |
| created_at | string(date-time) | false | none | none |
Pagination
{
"total": 0,
"page_no": 0,
"page_size": 0,
"total_pages": 0
}
Properties
| Name | Type | Required | Restrictions | Description |
|---|---|---|---|---|
| total | integer | false | none | none |
| page_no | integer | false | none | none |
| page_size | integer | false | none | none |
| total_pages | integer | false | none | none |